@@ -40,6 +40,8 @@ where
             return;
         }
 
+        self.vars.inline_with_multi_replacer(init);
+
         // TODO: Check for side effect between original decl position and inlined
         // position
 
@@ -435,6 +437,8 @@ where
             // Inline very simple functions.
             match decl {
                 Decl::Fn(f) if self.options.inline >= 2 && f.ident.sym != *"arguments" => {
+                    self.vars.inline_with_multi_replacer(&mut f.function.body);
+
                     match &f.function.body {
                         Some(body) => {
                             if !UsageFinder::find(&i, body)
